/**
 * Title: SessionBean
 * Description:
 * Copyright:    Copyright (c) 2009
 * Company:      Morpheus
 * @author Stefano Adriani
 * @version 1.0
 */

package adriani.webapp.beans ;

import adriani.webapp.util.* ;

import java.util.* ;
import javax.servlet.http.* ;

/**
* Bean managing the HTTP session for each user. This bean is created before the user login, hence it exists
* for each user, even if he's not logged in the webapp.<br/>
* This bean takes care of whatever concerns the session, hence the user's data must be managed by another
* bean (for example a <CODE>UsersBean</CODE> class).
*/
public class SessionBean extends GeneralBean {

	/** CLASS ATTRIBUTES																					*/
	private int pages ;								// Number of pages visited by the user	
	private String name ;							// Attribute used to test the setProperty mechanism
	private String sessionIP ;						// The IP address of the user when session is created
	private boolean isRegistered ;					// Specifies is the session is anonymous or autenticated.

	/** SESSION ATTRIBUTES																					*/
	private HttpSession httpSession ;
    private HttpServletRequest httpRequest ;
	private HttpServletResponse httpResponse ;

// ********************						CONSTRUCTOR							*****************************

	/** Mandatory EMPTY constructor, required by the JavaBeans implementation rules.										*/
    public SessionBean() { }

// ********************						MUTATORS							*****************************
// ********************			(methods reflecting the bean's logic)			*****************************

	/**
	* Store a reference to the current session IP into this bean.<br/>
	*/
    public void logSessionIP() {

		if (this.httpRequest != null) {
		  try {
			String sessionIP = httpRequest.getRemoteAddr() ;
			setSessionIP(sessionIP) ;
		  } catch (Exception e) {
	    	if (Settings.DEBUG) System.out.println("SessionBean: impossible to set the IP address") ;
    	  }
    	}
    }
	
// ********************					SAMPLE PROPERTIES					*************************************
// ********************		(used to test the properties set of this bean)	*************************************
	
	/** Set a general string value bound to the <code>name</code> property.										*/
    public void setName(String value) 				{		this.name = value ;							    	}

	/** Return the value bound to the <code>name</code> property.												*/
    public String getName() 						{       return this.name ;							   		}

// ********************					SESSION MANAGEMENT					*************************************
// ********************		(used to retrieve the properties of this bean)	*************************************

	/** Specifies if this user has already logged-in.															*/
    public void setRegistered(boolean value) 	{		this.isRegistered = value ;							    }

	/** Tells if this user has already logged-in.																*/
    public boolean isRegistered() 				{       return this.isRegistered ;							   	}

    /** Set the IP address at the moment of login.																*/
    public void setSessionIP(String address) 	{       this.sessionIP = address ;							   	}

    /** Returns the IP address at the moment of login.															*/
    public String getSessionIP() 				{       return this.sessionIP ;								    }

	/** Set the number of pages visited by the user in this session.											*/
    public void setPages(int value)				{		this.pages = value ;							   		}

	/** Return the number of pages visited by the user in this session.											*/
    public int getPages() 						{		return this.pages ;										}

// ************						REQUEST PROPERTIES								****************************
// ************		(managed by  <jsp:setProperty ...> and <jsp:getProperty ...>	****************************

	/** JavaBean property 																						*/
    public void setHttpSession(HttpSession httpSession) {
        this.httpSession = (HttpSession) httpSession ;
		if (Settings.DETAILS) System.out.println("SessionBean: setHttpSession") ;
    }

	/** JavaBean property 																						*/
    public HttpSession getHttpSession() {
        return this.httpSession ;
    }

	/** JavaBean property 																						*/
    public void setHttpRequest(HttpServletRequest httpRequest) {
        this.httpRequest = (HttpServletRequest) httpRequest ;
		if (Settings.DETAILS) System.out.println("SessionBean: setHttpRequest") ;		
    }

	/** JavaBean property 																						*/
    public HttpServletRequest getHttpRequest() {
        return this.httpRequest ;
    }

	/** JavaBean property 																						*/
    public void setHttpResponse(HttpServletResponse httpResponse) {
        this.httpResponse = (HttpServletResponse) httpResponse ;
		if (Settings.DETAILS) System.out.println("SessionBean: setHttpResponse") ;
    }

	/** JavaBean property 																						*/
    public HttpServletResponse getHttpResponse() {
        return this.httpResponse ;
    }

// ************************					UTILITIES					*****************************************	

    /** Count the pages visited by the user in this session.													*/
    public void countPages(int pages) 			{		this.pages += pages ;									}

} // END OF CLASS