/**
 * Title: ScopeService
 * Description:
 * Copyright:    Copyright (c) 2009
 * Company:      Morpheus
 * @author Stefano Adriani
 * @version 1.0
 */

package adriani.webapp.services ;

import java.util.* ;
import org.apache.axis2.context.* ;
import org.apache.axis2.description.* ;

/**
* Simple class used to verify how Axis2 handle persistence of the web services instances. This web service
* can be invoked from the page <code>test_scopeservice.jsp</code> many different times, and as long as the scope
* is set to "request" the client will get a different object for each request.<br/>
* Moreover, looking at the Tomcat console output, it's possibile to verify the FIRST INSTANCE of the
* web service is never finalized. This because at startup Axis2 prepares a pool of all the available web services,
* to improve performance, hence the first instance is always present.
*/
public class ScopeService {

	/** The leading name of each message logged on the STDOUT.											*/
	protected String leadingName = "ScopeService - " ;

	/**
	* The method representing the operation offered by this service.
	*
	* @param msg the string message used to produce the response message.
	*/
    public String echoMessage(String msg) {

		String result = "Hello " + msg + " from " + this + " [" + getThreadID() + "]" ;
		//System.out.println(leadingName + "Input: " + msg) ;
		
		this.delay() ;
		//System.out.println(leadingName + "Output: " + result) ;
        
		return result ;
    }
	
// **************************************************************************************************************	
// **********************************			 UTILITIES			 ********************************************
// **************************************************************************************************************	
	
	/**
	* Called by Axis2 at startup. If the scope is set to <code>application</code> when this method is called
	* the <code>ServiceContext</code> parameter contains a <em>null</em> <code>MessageContext</code> .
	*
	* @param serviceContext the service context handled by Axis2.
	*/
	public void init(ServiceContext serviceContext) {

		MessageContext messageContext 	= MessageContext.getCurrentMessageContext() ;
		StringBuffer text = new StringBuffer() ;
		text.append(leadingName + "Init method values:\n") ;
		text.append("Service object: " + this + "\n") ;

		// When scope = "application" the messageContext is always null !!!
		if (messageContext != null) {
			AxisService service 			= messageContext.getAxisService() ;
			AxisMessage message 			= messageContext.getAxisMessage() ;
			AxisOperation operation 		= messageContext.getAxisOperation() ;
			text.append("AxisService: " + service + "\n") ;
			text.append("AxisMessage: " + message + "\n") ;
			text.append("AxisOperation: " + operation + "\n") ;
			text.append("\n") ;
			System.out.println( text.toString() ) ;
		} else {
			System.out.println(leadingName + "Found null Message Context") ;
		}
	}

	/**
	* Used to delay the service response for about 1 second. 
	* This is not needed when calling the service from the <code>test_scopeservice.jsp</code>, 
	* but is's needed when testing the multi-threading behaviour.
	* See the <code>test_concurrent.jsp</code> for details.
	*/
	public void delay() {

		try { 
			Thread.currentThread().sleep(1000) ;
			//System.out.println(leadingName + "Sleeped: " + getThreadID()) ;						
		} catch (InterruptedException e) { 
			System.err.println(leadingName + "Interrupted while sleeping") ;	
		}
	}

	/**
	* Called by the Virtual Machine when this object is destroyed.
	*/
	public void finalize() {

		System.out.println(leadingName + "Finalized: " + this) ;
	}

// *************************************************************************************************************
// ***********************************		  METHODS NEVER USED		****************************************
// *************************************************************************************************************

	/**
	* This method should be called theoretically, but I have never seen it working.
	*/
	public void destroy(ServiceContext serviceContext) {

		System.out.println(leadingName + "Destroy: " + serviceContext) ;
	}

	/**
	* This method should be called theoretically, but I have never seen it working.
	*/
	public void setOperationContext(OperationContext operationContext) {

		System.out.println(leadingName + "SetOperationContext: " + operationContext) ;
	}
	
// **************************************************************************************************************	
// **********************************			   ACCESSORS			*****************************************
// **************************************************************************************************************	

	/**
	* Return the reference ID of the thread running this service.												
	*
	* @return the ID (as a long integer) of the current thread.
	*/
    public long getThreadID() {
	
		return Thread.currentThread().getId() ;	
	}

} // END OF CLASS