/**
 * Title: SimpleJava
 * Description:
 * Copyright:    Copyright (c) 2009
 * Company:      Morpheus
 * @author Stefano Adriani
 * @version 1.0
 */

package adriani.webapp.services ;

import java.util.* ;
import adriani.webapp.* ;

/**
* Very simple web service written in the "old java model", i.e. using just one Java Class to offer the service
* (a Plain Old Java Object).
*/
public class SimpleJava {

	/** If <code>true</code> very detailed messages are printed on the STDOUT							*/
	private boolean verbose = true ;

	/** CLASS ATTRIBUTES				*/	
    private HashMap map = new HashMap() ;

	/**
	* Return the value specified by the input key. If no key is found returns -1.<br/><br/>
	* <strong>Remark</strong>: the actual name of the input parameter should be defined by the WSDL file.
	* For example, if the WSDL file contains the following definition for <code>getValue</code>:<br/><br/>
	*
	* <code>&lt;xs:element minOccurs="0" name="param0" nillable="true" type="xs:string"/&gt;</code><br/><br/>
	*
	* Hence the HTTP call must use a parameter named <em>param0</em>, e.g. <code>/getvalue?param0=foo</code>.
	* For the same reason, a SOAP call must specify an input XML element named <em>&lt;param0&gt;</em>.
	*
	* @param key the input key (as a String)
	* @return the integer value bound to the input key
	*/
    public int getValue(String key) {

        Integer value = (Integer) map.get(key) ;
		if (verbose) System.out.println("SimpleJava input key=" + key) ;
        if (value != null) return value.intValue();
        return -1 ;
    }

	/**
	* Insert a new value in the inner HashMap. After this call, the pair key-value will be available
	* calling the <code>getValue<code> method.
	*
	* @param key the input key (as a String)
	* @param value the input value (as an integer)
	*/
    public void setValue(String key, int value) {

        map.put(key, new Integer(value)) ;
		if (verbose) System.out.println("SimpleJava setting=" + key + ":" + value) ;
    }

} // END OF CLASS
